// Bridge the JIL API to the widget object injected by android

var widget = {};
var Widget = widget;
android_init();

function android_init() {

  // Internal

  widget.android_event_listeners = [];

  widget.android_fire_resolution_event = function() {
    var listeners = widget.android_event_listeners;
    var length = listeners.length;
    for (var i = 0; i < length; i++) {
      listeners[i].call();
    }
  };

  widget.android_back=function() {
	  //
	  // set this var to your function which manages the back navigation
	  // and set call android.setBackButtonJSEnabled(true)
	  //
  };

  // Widget object

  widget.widgetMode = 'application';
  
  widget.addEventListener = function(event, handler, capture) {
    if (event == 'resolution') {
      widget.android_event_listeners.push(handler);
    }
  };

  widget.preferenceForKey = function(key) {
    var value = android.preferenceForKey(key);
    return (value != null ? String(value) : value);
  };

  widget.setPreferenceForKey = function(value, key) {
    android.setPreferenceForKey(value, key);
  };

  widget.openURL = function(url) {
    android.openURL(url);
  };
  
  widget.getAttention = function() {
    android.getAttention();
  };

  // Multimedia

  var javaMultimedia = android.getMultimedia();

  // Multimedia.AudioPlayer

  var javaAudioPlayer = javaMultimedia.getAudioPlayer();
  var audioPlayer = {
    open: function(uri) {
      javaAudioPlayer.open(uri);
    },
    pause: function() {
      javaAudioPlayer.pause();
    },
    play: function(times) {
      javaAudioPlayer.play(times);
    },
    resume: function() {
      javaAudioPlayer.resume();
    },
    stop: function() {
      javaAudioPlayer.stop();
    },
    onStateChangeCallback: function(state) {
      var audioPlayer = Widget.Multimedia.AudioPlayer;
      if (typeof(audioPlayer.onStateChange) != 'undefined' && audioPlayer.onStateChange != null) {
        audioPlayer.onStateChange(state);
      }
    }
  };

  widget.Multimedia = {
    AudioPlayer: audioPlayer
  };

  // Device

  var javaDevice = android.getDevice();

  // Device.DeviceStateInfo

  var javaDeviceStateInfo = javaDevice.getDeviceStateInfo();
  var deviceStateInfo = {
    requestPositionInfo: function(method) {
      javaDeviceStateInfo.requestPositionInfo(method);
    },
    onPositionRetrievedCallback: function(
      method, accuracy, altitude, altitudeAccuracy, longitude, latitude, cellID, timeStamp) {
      if (accuracy != null) {
        accuracy = parseFloat(accuracy.toString());
      }
      if (altitude != null) {
        altitude = parseFloat(altitude.toString());
      }
      if (altitudeAccuracy != null) {
        altitudeAccuracy = parseFloat(altitudeAccuracy.toString());
      }
      if (longitude != null) {
        longitude = parseFloat(longitude.toString());
      }
      if (latitude != null) {
        latitude = parseFloat(latitude.toString());
      }
      if (cellID != null) {
        cellID = parseInt(cellID.toString());
      }
      if (timeStamp != null) {
        timeStamp = new Date(parseInt(timeStamp.toString()));
      }
      Widget.Device.DeviceStateInfo.onPositionRetrieved(
        {
          accuracy: accuracy,
          altitude: altitude,
          altitudeAccuracy: altitudeAccuracy,
          longitude: longitude,
          latitude: latitude,
          cellID: cellID,
          timeStamp: timeStamp
        }, method.toString());
    }
  };

  widget.Device = {
    DeviceStateInfo: deviceStateInfo
  };

  // Messaging

  var javaMessaging = android.getMessaging();

  // Messaging.Message

  var Message = function(type) {
    this.javaMessage = javaMessaging.createMessage(type);

    this.addAddress = function(type, address) {
      this.javaMessage.addAddress(type, address);
    };
  };

  widget.Messaging = {
    createMessage: function(type) {
      var result = new Message(type);
      return result;
    },
    sendMessage: function(message) {
      var javaMessage = message.javaMessage;
      javaMessage.setBody(message.body);
      javaMessaging.sendMessage(javaMessage);
    }
  };

  // Telephony

  var javaTelephony = android.getTelephony();

  widget.Telephony = {
    initiateVoiceCall: function(phoneNumber) {
      javaTelephony.initiateVoiceCall(phoneNumber);
    }
  };
}
