/**
 * @author Vodafone D2 GmbH
 *
 * setLang writes the values of all elements, with a class name
 * beginning with "i18n_", in the requested language.
 * @param {String} language
 */
function setLang(language) {
	if (lang.title != undefined) {
		$('title').attr('lang', language).html(((lang.title[language] == undefined) ? lang.title[vf.defaultLanguage] : lang.title[language]));
	}
	$("[class^='i18n_']").each(function(){
		var t = $(this);
		var phrase = t.attr('class').split(' ');
		var curr ="";
		var i18n_text = "";
		jQuery.each(phrase, function(){
			if (this.beginsWith("i18n_", true) == true) {
				curr = this;
        i18n_text = i18nFor(curr, language);
        if (t.is(":button, :submit, :text, :reset")) {
          t.val((i18n_text));
        }
        else if (!t.is(":radio, :checkbox")) {
            t.html(i18n_text);
        }
      }
		});
  });
}

/**
 * i18nFor returns the i18n value for a certain class
 * @param {String} i18nClass
 * @param {String} language - optional, see comments in following code
 */

function i18nFor(i18nClass, language) {
  var lang_key = lang[i18nClass];
  var i18n_text = "";
  if (lang_key == undefined) {
    return i18nError("The key/value pair for "+i18nClass+ " is missing in lang.js");
  }
  else {
    /**
     * get document language if no language given
     */
    language = (language == undefined) ? vf.language : language;
    i18n_text = (lang_key[language] == undefined) ? lang_key[vf.defaultLanguage] : lang_key[language];
    /**
     * get default language if no value exists for current language
     */
    return (i18n_text == undefined) ? i18nError("The default key for "+i18nClass+ " is missing in lang.js", "Default?") : i18n_text;
  }
}

/**
 * i18nError returns the i18n value for a certain class
 * @param {String} msg - Message text
 * @param {String} returnVal - optional, Value to be returned, default is "UNDEFINED"
 */

function i18nError(msg, returnVal) {
  vf.debug = 1;
  $('body').append('<div id="debug"></div>');
  vf.log(msg);
  return (returnVal == undefined ) ? "UNDEFINED" : returnVal;
  vf.debug = 0;
}